@@ -18,10 +18,10 @@ sub cold {
     $mapping //= {};
 
     # Syntax check
-    croak 'Invalid syntax in marble diagram of cold' if $marble !~ /^((?:\((?:[a-z0-9]|\|)+?\))|-|[a-z0-9]|\|)*\z/gx;
+    croak 'Invalid syntax in marble diagram of cold' if $marble !~ /^((?:\((?:[a-z0-9|#])+?\))|[a-z0-9|#-])*\z/gx;
     pos $marble = 0;
 
-    my @tokens = $marble =~ /[a-z0-9]|\(|\)|\-|\|/g;
+    my @tokens = $marble =~ /[a-z0-9\(\)\-\|\#]/g;
 
     my @components;
     my $time = 0;
@@ -47,6 +47,12 @@ sub cold {
                 push @components, rx_EMPTY->pipe(op_delay($time));
             }
             last TOKEN;
+        } elsif ($token eq '#') {
+            push @components, rx_concat(
+                rx_EMPTY->pipe(op_delay($time)),
+                rx_throw_error,
+            );
+            last TOKEN;
         }
     }
 
